@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import pathlib
 from collections import OrderedDict
-from collections.abc import Iterable, MutableMapping
+from collections.abc import Iterable, MutableMapping, Sequence
 from typing import Any, TypedDict
 
 # Type
@@ -35,6 +35,8 @@ class Settings(TypedDict, total=False):
     version_scheme: str | None
     version_type: str | None
     tag_format: str
+    legacy_tag_formats: Sequence[str]
+    ignored_tag_formats: Sequence[str]
     bump_message: str | None
     retry_after_failure: bool
     allow_abort: bool
@@ -77,6 +79,8 @@ DEFAULT_SETTINGS: Settings = {
     "version_provider": "commitizen",
     "version_scheme": None,
     "tag_format": "$version",  # example v$version
+    "legacy_tag_formats": [],
+    "ignored_tag_formats": [],
     "bump_message": None,  # bumped v$current_version to $new_version
     "retry_after_failure": False,
     "allow_abort": False,
@@ -138,17 +142,15 @@ bump_message = "bump: version $current_version → $new_version"
 def get_tag_regexes(
     version_regex: str,
 ) -> dict[str, str]:
+    regexs = {
+        "version": version_regex,
+        "major": r"(?P<major>\d+)",
+        "minor": r"(?P<minor>\d+)",
+        "patch": r"(?P<patch>\d+)",
+        "prerelease": r"(?P<prerelease>\w+\d+)?",
+        "devrelease": r"(?P<devrelease>\.dev\d+)?",
+    }
     return {
-        "$version": version_regex,
-        "$major": r"(?P<major>\d+)",
-        "$minor": r"(?P<minor>\d+)",
-        "$patch": r"(?P<patch>\d+)",
-        "$prerelease": r"(?P<prerelease>\w+\d+)?",
-        "$devrelease": r"(?P<devrelease>\.dev\d+)?",
-        "${version}": version_regex,
-        "${major}": r"(?P<major>\d+)",
-        "${minor}": r"(?P<minor>\d+)",
-        "${patch}": r"(?P<patch>\d+)",
-        "${prerelease}": r"(?P<prerelease>\w+\d+)?",
-        "${devrelease}": r"(?P<devrelease>\.dev\d+)?",
+        **{f"${k}": v for k, v in regexs.items()},
+        **{f"${{{k}}}": v for k, v in regexs.items()},
     }
